internal/dl: update for relui

Update the comment about where to update the File struct, add relui to
the list of allowed website publishers, and while I'm here remove some
former team members.

For golang/go#51797.

Change-Id: I8ca2f65d8d41145914f0adc0d04cdba6f230cd85
Reviewed-on: https://go-review.googlesource.com/c/website/+/411174
Run-TryBot: Heschi Kreinick <heschi@google.com>
TryBot-Result: Gopher Robot <gobot@golang.org>
Reviewed-by: Dmitri Shuralyov <dmitshur@google.com>
Reviewed-by: Dmitri Shuralyov <dmitshur@golang.org>
diff --git a/internal/dl/dl.go b/internal/dl/dl.go
index 0069d0b..44fe132 100644
--- a/internal/dl/dl.go
+++ b/internal/dl/dl.go
@@ -41,7 +41,7 @@
 )
 
 // File represents a file on the go.dev downloads page.
 // It should be kept in sync with the upload code in x/build/cmd/release.
 type File struct {
 	Filename       string    `json:"filename"`
 	OS             string    `json:"os"`
@@ -347,7 +347,9 @@
 // Go release binaries via the /dl/upload endpoint.
 func validUser(user string) bool {
 	switch user {
-	case "amedee", "cherryyz", "dmitshur", "drchase", "heschi", "katiehockman", "mknyszek", "rakoczy", "thanm", "valsorda":
+	case "amedee", "cherryyz", "dmitshur", "drchase", "heschi", "mknyszek", "rakoczy", "thanm":
+		return true
+	case "relui":
 		return true
 	}
 	return false
@@ -41,7 +41,7 @@
 
 // File represents a file on the go.dev downloads page.
-// It should be kept in sync with the upload code in x/build/cmd/release.
+// It should be kept in sync with the upload code in x/build/internal/relui.
 type File struct {
 	Filename       string    `json:"filename"`